@@ -17,8 +17,8 @@ def _match(column_instance: InstrumentedAttribute, compare_value: str, invert=Fa
     """
     Create Column based Compare logic
 
-    For building filters, the Column should be filtered for 
-    records that match the given value. If the compare value 
+    For building filters, the Column should be filtered for
+    records that match the given value. If the compare value
     contains a `'%'` or `'*'`, a LIKE clause instrumenting this
     wildcard will be used, otherwise an exact match.
     If the string startswith `!`, the filter will be inverted.
@@ -30,29 +30,29 @@ def _match(column_instance: InstrumentedAttribute, compare_value: str, invert=Fa
     compare_value : str
         Matching string that should be used.
     invert : bool
-        If True, a unary `not` will be placed on the comparison. 
+        If True, a unary `not` will be placed on the comparison.
         This is not actually used in the models. Defaults to False.
-    
+
     Returns
     -------
     expression : sqlalchemy.BinaryExpression
-        The returned BinaryExpression can directly be passed to 
+        The returned BinaryExpression can directly be passed to
         sqlalchemy's filter function on Query objects.
-    
+
     TODO
     ----
     here, we could check the content for `[]` and apply regex.
-     
+
     """
     # check invert
     if compare_value.startswith('!'):
         invert = True
         compare_value = compare_value[1:]
-    
+
     # check for asterisk
     if '*' in compare_value:
         compare_value = compare_value.replace('*', '%')
-    
+
     # check for the right variant
     if '%' in compare_value:
         if invert:
@@ -69,7 +69,7 @@ def _match(column_instance: InstrumentedAttribute, compare_value: str, invert=Fa
 def find_keyword(session, id=None, uuid=None, value=None, thesaurus_name=None, return_iterator=False):
     """Find keyword
 
-    Return one or many keyword entries from the database on 
+    Return one or many keyword entries from the database on
     exact matches.
 
     Parameters
@@ -77,12 +77,12 @@ def find_keyword(session, id=None, uuid=None, value=None, thesaurus_name=None, r
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     uuid : str
         .. versionadded:: 0.1.13
         Find by version 4 UUID. If uuid is given, all other options
-        will be ignored. 
+        will be ignored.
     value : str
         Value of the requested keyword(s). Multiple record
         return is possible.
@@ -92,9 +92,9 @@ def find_keyword(session, id=None, uuid=None, value=None, thesaurus_name=None, r
         At the current stage, only 'GCMD' science keywords are
         implemented.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
     Returns
     -------
     records : list of metacatalog.Keyword
@@ -130,8 +130,8 @@ def find_thesaurus(session, id=None, name=None, title=None, organisation=None, d
     """Find Thesaurii
     ..versionadded:: 0.1.10
 
-    Retun one or many thesaurii references from the database 
-    on exact matches. You can  use `'%'` and `'*'` as wildcards 
+    Retun one or many thesaurii references from the database
+    on exact matches. You can  use `'%'` and `'*'` as wildcards
     and prepend a str with `!` to invert the filter.
 
     Parameters
@@ -139,7 +139,7 @@ def find_thesaurus(session, id=None, name=None, title=None, organisation=None, d
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     name : str
         Short name of the Thesaurus. No wildcard use is possible.
@@ -148,13 +148,13 @@ def find_thesaurus(session, id=None, name=None, title=None, organisation=None, d
         Full title attribute of the requested thesaurii.
         Multiple record return is possible.
     organisation : str
-        Organisation name of the requested thesaurii. 
+        Organisation name of the requested thesaurii.
         Multiple record return is possible.
-    description : str 
-        Description of the thesaurus. The decription field 
+    description : str
+        Description of the thesaurus. The decription field
         is optional and some records may not be found.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
 
     Returns
@@ -177,7 +177,7 @@ def find_thesaurus(session, id=None, name=None, title=None, organisation=None, d
         query = query.filter(_match(models.Thesaurus.organisation, organisation))
     if description is not None:
         query = query.filer(_match(models.Thesaurus.description, description))
-    
+
     # return
     if return_iterator:
         return query
@@ -188,12 +188,12 @@ def find_thesaurus(session, id=None, name=None, title=None, organisation=None, d
 def find_license(session, id=None, title=None, short_title=None, by_attribution=None, share_alike=None, commercial_use=None, return_iterator=False):
     """Find license
 
-    Return one or many license entries from the database on 
-    exact matches. You can  use `'%'` and `'*'` as wildcards 
+    Return one or many license entries from the database on
+    exact matches. You can  use `'%'` and `'*'` as wildcards
     and prepend a str with `!` to invert the filter.
 
     .. versionchanged:: 0.1.8
-        string matches now allow `'%'` and `'*'` wildcards and can 
+        string matches now allow `'%'` and `'*'` wildcards and can
         be inverted by prepending `!`
 
     Parameters
@@ -201,14 +201,14 @@ def find_license(session, id=None, title=None, short_title=None, by_attribution=
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     title : str
         .. versionadded:: 0.1.8
         Full title attribute of the requested license(s).
         Multiple record return is possible.
     short_title : str
-        short_title attribute of the requested license(s). 
+        short_title attribute of the requested license(s).
         Multiple record return is possible.
     by_attribution : bool
         by_attribution attribute of the requested license(s).
@@ -220,9 +220,9 @@ def find_license(session, id=None, title=None, short_title=None, by_attribution=
         by_attribution attribute of the requested license(s).
         Multiple record return is possible.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
     Returns
     -------
     records : list of metacatalog.License
@@ -244,7 +244,7 @@ def find_license(session, id=None, title=None, short_title=None, by_attribution=
         query = query.filter(models.License.share_alike==share_alike)
     if commercial_use is not None:
         query = query.filter(models.License.commercial_use==commercial_use)
-    
+
     # return
     if return_iterator:
         return query
@@ -255,12 +255,12 @@ def find_license(session, id=None, title=None, short_title=None, by_attribution=
 def find_unit(session, id=None, name=None, symbol=None, return_iterator=False):
     """Find Unit
 
-    Return one unit entry from the database on 
-    exact matches. It makes only sense to set one of the 
+    Return one unit entry from the database on
+    exact matches. It makes only sense to set one of the
     attributes (id, name, symbol).
 
     .. versionchanged:: 0.1.8
-        string matches now allow `'%'` and `'*'` wildcards and can 
+        string matches now allow `'%'` and `'*'` wildcards and can
         be inverted by prepending `!`
 
     Parameters
@@ -268,20 +268,20 @@ def find_unit(session, id=None, name=None, symbol=None, return_iterator=False):
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     name : str
-        name attribute of the requested unit. 
+        name attribute of the requested unit.
     symbol : str
         symbol attribute of the requested unit.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
     Returns
     -------
     records : list of metacatalog.Unit
-        List of matched Unit instance. 
+        List of matched Unit instance.
 
     """
     # base query
@@ -304,12 +304,12 @@ def find_unit(session, id=None, name=None, symbol=None, return_iterator=False):
 def find_variable(session, id=None, name=None, symbol=None, return_iterator=False):
     """Find Variable
 
-    Return one vriable entry from the database on 
-    exact matches. It makes only sense to set one of the 
+    Return one vriable entry from the database on
+    exact matches. It makes only sense to set one of the
     attributes (id, name, symbol).
 
     .. versionchanged:: 0.1.8
-        string matches now allow `'%'` and `'*'` wildcards and can 
+        string matches now allow `'%'` and `'*'` wildcards and can
         be inverted by prepending `!`
 
     Parameters
@@ -317,20 +317,20 @@ def find_variable(session, id=None, name=None, symbol=None, return_iterator=Fals
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     name : str
-        name attribute of the requested variable. 
+        name attribute of the requested variable.
     symbol : str
         symbol attribute of the requested variable.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
     Returns
     -------
     records : list of metacatalog.Variable
-        List of matched Variable instance. 
+        List of matched Variable instance.
 
     """
     # base query
@@ -353,30 +353,30 @@ def find_variable(session, id=None, name=None, symbol=None, return_iterator=Fals
 def find_datasource_type(session, id=None, name=None, return_iterator=False):
     """Find Datasource Type
 
-    Return one datasource type record on exact matches. 
+    Return one datasource type record on exact matches.
     Types can be identified by id or name.
 
     .. versionchanged:: 0.1.8
-        string matches now allow `'%'` and `'*'` wildcards and can 
+        string matches now allow `'%'` and `'*'` wildcards and can
         be inverted by prepending `!`
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     name : str
-        name attribute of the requested type. 
+        name attribute of the requested type.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
     Returns
     -------
     records : list of metacatalog.DataSourceType
-        List of matched DataSourceType instance. 
+        List of matched DataSourceType instance.
 
     """
     # base query
@@ -387,40 +387,40 @@ def find_datasource_type(session, id=None, name=None, return_iterator=False):
     if name is not None:
         query = query.filter(_match(models.DataSourceType.name, name))
 
-    # return 
+    # return
     if return_iterator:
         return query
-    else: 
+    else:
         return query.all()
 
 
 def find_role(session, id=None, name=None, return_iterator=False):
     """Find Person Role
 
-    Return one person role record on exact matches. 
+    Return one person role record on exact matches.
     Roles can be identified by id or name.
 
     .. versionchanged:: 0.1.8
-        string matches now allow `'%'` and `'*'` wildcards and can 
+        string matches now allow `'%'` and `'*'` wildcards and can
         be inverted by prepending `!`
 
     Parameters
     ----------
-   session : sqlalchemy.Session
+    session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     name : str
-        name attribute of the requested role. 
+        name attribute of the requested role.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
     Returns
     -------
     records : list of metacatalog.PersonRole
-        List of matched PersonRole instance. 
+        List of matched PersonRole instance.
 
     """
     # base query
@@ -438,16 +438,16 @@ def find_role(session, id=None, name=None, return_iterator=False):
         return query.all()
 
 
-def find_person(session, id=None, first_name=None, last_name=None, role=None, organisation_name=None, organisation_abbrev=None, return_iterator=False):
+def find_person(session, id=None, uuid=None, first_name=None, last_name=None, role=None, organisation_name=None, organisation_abbrev=None, return_iterator=False):
     """Find Person
 
-    Return person record on exact matches. Persons can be 
+    Return person record on exact matches. Persons can be
     identified by id, first_name, last_name, organisation details or associated roles.
-    Since version ``0.2.5`` only Persons which have a ``is_organisation==False`` 
+    Since version ``0.2.5`` only Persons which have a ``is_organisation==False``
     will be returned
 
     .. versionchanged:: 0.1.8
-        string matches now allow `'%'` and `'*'` wildcards and can 
+        string matches now allow `'%'` and `'*'` wildcards and can
         be inverted by prepending `!`
 
     .. versaionchanged:: 0.2.6
@@ -458,18 +458,22 @@ def find_person(session, id=None, first_name=None, last_name=None, role=None, or
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
+    uuid : str
+        .. versionadded:: 0.2.7
+        Find by version 4 UUID. If uuid is given, all other options
+        will be ignored.
     first_name : str
-        First name attribute of the requested person. 
+        First name attribute of the requested person.
     last_name : str
         Last name attribute of the requested person.
     role : int, str
-        Role id or name (exact match) that is associated to 
+        Role id or name (exact match) that is associated to
         a person. Will most likely return many persons.
     organisation_name :  str
         .. versionadded:: 0.1.10
-        The name of the head organisation, without department 
+        The name of the head organisation, without department
         and group specification.
         .. note::
             Not all Persons may have an organisation_name.
@@ -480,13 +484,13 @@ def find_person(session, id=None, first_name=None, last_name=None, role=None, or
         .. note::
             Not all Persons may have a head organisation
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
     Returns
     -------
     records : list of metacatalog.Person
-        List of matched Person instance. 
+        List of matched Person instance.
 
     See Also
     --------
@@ -496,15 +500,23 @@ def find_person(session, id=None, first_name=None, last_name=None, role=None, or
     # base query
     query = session.query(models.Person).filter(models.Person.is_organisation == false())
 
+    # handle uuid first
+    if uuid is not None:
+        query = query.filter(models.Person.uuid==uuid)
+        if return_iterator:
+            return query
+        else:
+            return query.first()
+
     if id is not None:
         query = query.filter(models.Person.id==id)
-    
+
     if first_name is not None:
         query = query.filter(_match(models.Person.first_name, first_name))
-    
+
     if last_name is not None:
         query = query.filter(_match(models.Person.last_name, last_name))
-    
+
     if role is not None:
         # get the roles
         if isinstance(role, int):
@@ -513,7 +525,7 @@ def find_person(session, id=None, first_name=None, last_name=None, role=None, or
             role_id = session.query(models.PersonRole.id).filter(models.PersonRole.name==role).first()
         else:
             raise AttributeError('Role has to be an id (integer) or name (string).')
-        
+
         # find the associations
         ids = session.query(models.PersonAssociation.person_id).filter(models.PersonAssociation.relationship_type_id==role_id).all()
 
@@ -525,7 +537,7 @@ def find_person(session, id=None, first_name=None, last_name=None, role=None, or
 
     if organisation_abbrev is not None:
         query = query.filter(_match(models.Person.organisation_abbrev, organisation_abbrev))
-    
+
     # return
     if return_iterator:
         return query
@@ -537,33 +549,33 @@ def find_organisation(session, id=None, organisation_name=None, organisation_abb
     """Find Organisation
     .. versionadded:: 0.2.6
 
-    Return Person record on exact matches. This function will only return records 
-    that have ``is_organisation=True``. For natural persons use the 
-    :func:`find_person <metacatalog.api.find_person>` function.    
+    Return Person record on exact matches. This function will only return records
+    that have ``is_organisation=True``. For natural persons use the
+    :func:`find_person <metacatalog.api.find_person>` function.
 
     Parameters
     ----------
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     organisation_name :  str
-        Required. The full name of the head organisation. 
+        Required. The full name of the head organisation.
     organisation_abbrev : str
         A short abbreviation of the head organisation if
         applicable.
     role : int, str
-        Role id or name (exact match) that is associated to 
+        Role id or name (exact match) that is associated to
         an organistion. Will most likely return many organisations.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
     Returns
     -------
     records : list of metacatalog.Person
-        List of matched Person instance. 
+        List of matched Person instance.
 
     """
     # base query
@@ -606,10 +618,10 @@ def find_group_type(session, id=None, uuid=None, name=None, return_iterator=Fals
     """Find entry group types
 
     Find a group type on exact matches. The group types
-    describes a collection of entries. 
+    describes a collection of entries.
 
     .. versionchanged:: 0.1.8
-        string matches now allow `'%'` and `'*'` wildcards and can 
+        string matches now allow `'%'` and `'*'` wildcards and can
         be inverted by prepending `!`
 
     Parameters
@@ -617,18 +629,18 @@ def find_group_type(session, id=None, uuid=None, name=None, return_iterator=Fals
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     name : str
         Name attribute of the group type.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
     Returns
     -------
     records : list of metacatalog.EntryGroupType
-        List of matched EntryGroupType instance. 
+        List of matched EntryGroupType instance.
 
     """
     # base query
@@ -639,7 +651,7 @@ def find_group_type(session, id=None, uuid=None, name=None, return_iterator=Fals
     if name is not None:
         query = query.filter(_match(models.EntryGroupType.name, name))
 
-    # return 
+    # return
     if return_iterator:
         return query
     else:
@@ -649,11 +661,11 @@ def find_group_type(session, id=None, uuid=None, name=None, return_iterator=Fals
 def find_group(session, id=None, uuid=None, title=None, type=None, return_iterator=False):
     """Find group
 
-    Find a group of entries on exact matches. Groups can be 
+    Find a group of entries on exact matches. Groups can be
     identified by id, title or its type.
 
     .. versionchanged:: 0.1.8
-        string matches now allow `'%'` and `'*'` wildcards and can 
+        string matches now allow `'%'` and `'*'` wildcards and can
         be inverted by prepending `!`
 
     Parameters
@@ -661,24 +673,24 @@ def find_group(session, id=None, uuid=None, title=None, type=None, return_iterat
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     uuid : str
         .. versionadded:: 0.1.13
         Find by version 4 UUID. If uuid is given, all other options
-        will be ignored. 
+        will be ignored.
     title : str
         Title attribute of the group.
     type : int, str
         Either the id or name of a group type to exact match.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
     Returns
     -------
     records : list of metacatalog.EntryGroupType
-        List of matched EntryGroupType instance. 
+        List of matched EntryGroupType instance.
 
     """
     # base query
@@ -706,7 +718,7 @@ def find_group(session, id=None, uuid=None, title=None, type=None, return_iterat
             raise AttributeError('Type has to be an id (integer) or type name (string).')
 
         query = query.filter(models.EntryGroup.type_id==grouptype.id)
-    
+
     # return
     if return_iterator:
         return query
@@ -717,13 +729,13 @@ def find_group(session, id=None, uuid=None, title=None, type=None, return_iterat
 def find_entry(session, id=None, uuid=None, title=None, abstract=None, license=None, variable=None, external_id=None, version='latest', project=None, author=None, contributor=None, keywords=None, details=None, return_iterator=False):
     """Find Entry
 
-    Find an meta data Entry on exact matches. Entries can be 
-    identified by id, title, external_id and version. The 
-    version can be added to all other matching types, which 
+    Find an meta data Entry on exact matches. Entries can be
+    identified by id, title, external_id and version. The
+    version can be added to all other matching types, which
     are mutually exclusive.
 
     .. versionchanged:: 0.1.8
-        string matches now allow `'%'` and `'*'` wildcards and can 
+        string matches now allow `'%'` and `'*'` wildcards and can
         be inverted by prepending `!`
 
     Parameters
@@ -731,82 +743,82 @@ def find_entry(session, id=None, uuid=None, title=None, abstract=None, license=N
     session : sqlalchemy.Session
         SQLAlchemy session connected to the database.
     id : integer
-        Database unique ID of the requested record. Will 
+        Database unique ID of the requested record. Will
         return only one record.
     uuid : str
         .. versionadded:: 0.1.13
         Find by version 4 UUID. If uuid is given, all other options
-        will be ignored. 
+        will be ignored.
     title : str
         Title attribute of the Entry.
     abstract : str
         .. versionadded:: 0.1.8
-        
+
         Abstract attibute of the Entry.
-        
+
         .. note::
             The abstract is usually a full text and the FIND operation
             uses **exact** matches. Therefore be sure to use a wildcard
-        
+
         .. code-block:: python
             api.find_entry(session, abstract='*phrase to find*')
     license : str, int
         .. versionadded:: 0.2.2
-        The license can be a :class:``License <metacatalog.models.License>`, 
-        its id (int) or the short_title (str).   
+        The license can be a :class:``License <metacatalog.models.License>`,
+        its id (int) or the short_title (str).
     variable : str, int
         .. versionadded:: 0.2.2
         The variable can be a :class:`Variable <metacatalog.models.Variable>`,
-        its id (int) or the name (str).  
+        its id (int) or the name (str).
     external_id : str
         External id attrinbute of the Entry.
     version : int, str
         .. versionchanged:: 0.2
             The default value is now 'latest'
-        
-        Version number of the Entry. Can be combined with 
-        the other matching parameters, as they might not be 
+
+        Version number of the Entry. Can be combined with
+        the other matching parameters, as they might not be
         different between versions.
         If version == 'latest', only the latest version will be found.
         If None, all version are integrated.
     project : int, str
         .. versionadded:: 0.2.2
-        The project can be a :class:`EntryGroup <metacatalog.models.EntryGroup>` of 
-        :class:`EntryGroupType.name=='Project' <metacatalog.models.EntryGroupType>`, 
+        The project can be a :class:`EntryGroup <metacatalog.models.EntryGroup>` of
+        :class:`EntryGroupType.name=='Project' <metacatalog.models.EntryGroupType>`,
         its id (int) or title (str)
     author : int, str
         .. versionadded:: 0.2.2
-        The author can be a :class:`Person <metacatalog.models.Person>`, 
-        his id (int) or name (str). A string argument will match first and last 
-        names. The author is only the first author. For other contributors see 
+        The author can be a :class:`Person <metacatalog.models.Person>`,
+        his id (int) or name (str). A string argument will match first and last
+        names. The author is only the first author. For other contributors see
         :attr:`contributor`.
     contributor : int, str
         .. versionadded:: 0.2.2
-        The contributor can be a :class:`Person <metacatalog.models.Person>`, 
-        his id (int) or name (str). A string argument will match first and last 
-        names. A contributor is anyone associated as first or co-author. For 
+        The contributor can be a :class:`Person <metacatalog.models.Person>`,
+        his id (int) or name (str). A string argument will match first and last
+        names. A contributor is anyone associated as first or co-author. For
         first author only, see :attr:`author`.
     keywords : list of str, int
         .. versionadded:: 0.2.2
-        The entries can be filtered by tagged controlled keywords. The given 
-        keyword or list of keywords will be matched against the value (str)  or 
-        id (int). If more than one is given, the entries need to be tagged by 
+        The entries can be filtered by tagged controlled keywords. The given
+        keyword or list of keywords will be matched against the value (str)  or
+        id (int). If more than one is given, the entries need to be tagged by
         **all** keywords. An ``OR`` search is not possible, through the API.
     details : dict
         ..versionadded:: 0.2.2
-        Entries can be filtered by additional details. The details need to be 
-        specified as dictioniares of ``name=value`` pairs. If more than one 
+        Entries can be filtered by additional details. The details need to be
+        specified as dictioniares of ``name=value`` pairs. If more than one
         pair is given, the query will combine the pairs by ``AND``.
         An ``OR`` search is not possible, through the API.
     return_iterator : bool
-        If True, an iterator returning the requested objects 
+        If True, an iterator returning the requested objects
         instead of the objects themselves is returned.
-    
+
 
     Returns
     -------
     records : list of metacatalog.Entry
-        List of matched Entry instance. 
+        List of matched Entry instance.
     """
     # handle uuid first
     if uuid is not None:
@@ -823,7 +835,7 @@ def find_entry(session, id=None, uuid=None, title=None, abstract=None, license=N
     if version == 'latest':
         query = query.filter(models.Entry.latest_version_id.is_(None))
         version = None
-    
+
     # now the remaining parameters
     if id is not None:
         query = query.filter(models.Entry.id==id)
@@ -843,14 +855,14 @@ def find_entry(session, id=None, uuid=None, title=None, abstract=None, license=N
     # license
     if license is not None:
         if isinstance(license, models.License):
-            license = license.id 
+            license = license.id
         if isinstance(license, int):
             query = query.filter(models.Entry.license_id==license)
         elif isinstance(license, str):
             query = query.join(models.License).filter(_match(models.License.short_title, license))
-        else: 
+        else:
             raise AttributeError('license has to be int or str.')
-    
+
     # variable
     if variable is not None:
         if isinstance(variable, models.Variable):
@@ -868,7 +880,7 @@ def find_entry(session, id=None, uuid=None, title=None, abstract=None, license=N
             if project.type.name != 'Project':
                 raise TypeError("EntryGroup has to be of type 'Project'.")
             project = project.id
-        if isinstance(project, int): 
+        if isinstance(project, int):
             join = query.join(models.EntryGroupAssociation).join(models.EntryGroup).join(models.EntryGroupType)
             query = join.filter(models.EntryGroupType.name=='Project').filter(models.EntryGroup.id==project)
         elif isinstance(project, str):
@@ -889,9 +901,9 @@ def find_entry(session, id=None, uuid=None, title=None, abstract=None, license=N
             query = join.filter(models.PersonRole.name=='author').filter(
                 (_match(models.Person.first_name, author)) | (_match(models.Person.last_name, author))
             )
-        else: 
+        else:
             raise AttributeError('author has to be int or str')
-    
+
     # contributor
     if contributor is not None:
         if isinstance(contributor, models.Person):
@@ -916,13 +928,13 @@ def find_entry(session, id=None, uuid=None, title=None, abstract=None, license=N
         for keyword in keywords:
             if isinstance(keyword, models.Keyword):
                 keyword = keyword.id
-            if isinstance(keyword, int):                
+            if isinstance(keyword, int):
                 query = query.filter(models.Keyword.id==keyword)
             elif isinstance(keyword, str):
                 query = query.filter(_match(models.Keyword.value, keyword))
             else:
                 raise AttributeError('keywords have to be a list of int or str')
-    
+
     # details
     if details is not None:
         # build the query
